import requests
from .classes import Contact, Email
from . import classes

class Server(classes.Server):
   def __init__(self, url, apiKey):
      self.url = url
      self.apiKey = apiKey

   def connect(self):
      pass

   # FixMe: [correctness] Support more than one recipient
   # FixMe: [correctness] Support cc and bcc fields
   def send(self, email):
      headers = {
         'Authorization': 'Bearer {}'.format(self.apiKey)
      }

      payload = {
         'from': email.sender.email,
         'fromname': email.sender.name,
         'to': email.receivers[0].email,
         'toname': email.receivers[0].name,
         'subject': email.subject,
         'html': email.body
      }

      requests.post(sendgridUrl, headers=headers, data=payload)



class Contact:
   def __init__(self, name, email):
      self.name = name
      self.email = email

class Server:
   def __init__(self):
      pass

   def connect(self):
      pass

   def send(self, email):
      raise NotImplementedError

class Email:
   def __init__(self, sender, receivers, subject, body,
                cc=[], bcc=[]):
      self.sender = sender
      self.receivers = receivers
      self.cc = cc
      self.bcc = bcc
      self.subject = subject
      self.body = body



import smtplib
from email.mime.text import MIMEText
from email.header import Header
from .classes import Contact, Email
from . import classes

def _outputContact(contact):
   return "{} <{}>".format(contact.name, contact.email)

def _outputEmail(email):
   toOutput = ",".join(_outputContact(c) for c in email.receivers)

   msg = MIMEText(email.body, _charset="UTF-8")
   msg['Subject'] = Header(email.subject, "utf-8")
   msg['From'] = _outputContact(email.sender)
   msg['To'] = toOutput
   if len(email.cc) != 0:
      ccOutput = ",".join(_outputContact(c) for c in email.cc)
      msg['Cc'] = ccOutput
   return msg.as_string()

class Server(classes.Server):
   def __init__(self, domain, port, sender, password):
      self.domain = domain
      self.port = port
      self.sender = sender
      self.password = password

   def connect(self):
      self.smtpObj = smtplib.SMTP_SSL(self.domain, self.port)
      self.smtpObj.login(self.sender.email, self.password)

   def send(self, email):
      toAddrs = [c.email for c in email.receivers] + \
                [c.email for c in email.cc] + \
                [c.email for c in email.bcc]
      self.smtpObj.sendmail(self.sender.email, toAddrs,
                            _outputEmail(email))



"""PySend
"""

from setuptools import setup, find_packages
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='pysend',

    version='0.0.4',

    description='Unified interface for sending email',
    long_description=long_description,

    url='https://github.com/growdaisy/pysend',

    author='Pokey Rule',
    author_email='pokey@growdaisy.com',

    license='MIT',

    classifiers=[
        'Development Status :: 3 - Alpha',

        'Intended Audience :: Developers',
        'Topic :: Communications :: Email',

        'License :: OSI Approved :: MIT License',

        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
    ],

    keywords='email smtp sendgrid',

    packages=find_packages(exclude=['contrib', 'docs', 'tests*']),

    install_requires=['requests'],
)
